about summary refs log tree commit diff
path: root/src/libstd
diff options
context:
space:
mode:
authorTim Diekmann <tim.diekmann@3dvision.de>2020-01-23 01:49:29 +0100
committerTim Diekmann <tim.diekmann@3dvision.de>2020-01-27 21:39:51 +0100
commit7ca25db8162128808714f536fa993aefcf6a2239 (patch)
treeb0e326ad284fb34d208b59080a38e349a50687b0 /src/libstd
parentc2d141df59703393c0c683abc259f9a8c3be041a (diff)
downloadrust-7ca25db8162128808714f536fa993aefcf6a2239.tar.gz
rust-7ca25db8162128808714f536fa993aefcf6a2239.zip
Rename `Alloc` to `AllocRef`
Diffstat (limited to 'src/libstd')
-rw-r--r--src/libstd/alloc.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/libstd/alloc.rs b/src/libstd/alloc.rs
index 7fd55af1694..8965c6860c4 100644
--- a/src/libstd/alloc.rs
+++ b/src/libstd/alloc.rs
@@ -133,9 +133,9 @@ pub use alloc_crate::alloc::*;
 #[derive(Debug, Default, Copy, Clone)]
 pub struct System;
 
 // The Alloc impl just forwards to the GlobalAlloc impl, which is in `std::sys::*::alloc`.
 #[unstable(feature = "allocator_api", issue = "32838")]
-unsafe impl Alloc for System {
+unsafe impl AllocRef for System {
     #[inline]
     unsafe fn alloc(&mut self, layout: Layout) -> Result<NonNull<u8>, AllocErr> {
         NonNull::new(GlobalAlloc::alloc(self, layout)).ok_or(AllocErr)
@@ -133,9 +133,9 @@ pub use alloc_crate::alloc::*;
 pub struct System;
 
-// The Alloc impl just forwards to the GlobalAlloc impl, which is in `std::sys::*::alloc`.
+// The AllocRef impl just forwards to the GlobalAlloc impl, which is in `std::sys::*::alloc`.
 #[unstable(feature = "allocator_api", issue = "32838")]